<?php

/**
 * @file
 * Drupal site-specific configuration file.
 *
 * @see default.settings.php for more information.
 */

// Set debug.
$debug = filter_var($_ENV['DEBUG'], FILTER_VALIDATE_BOOLEAN);

// Exclude modules from configuration synchronization.
$settings['config_exclude_modules'] = ['devel'];

// Salt for one-time login links, cancel links, form tokens, etc.
$settings['hash_salt'] = $_ENV['HASH_SALT'];

// Patterns for hosts to trust.
$settings['trusted_host_patterns'] = array_map('trim', explode(',', $_ENV['TRUSTED_HOST_PATTERN']));

// Private files path.
$settings['file_private_path'] = $app_root . '/../private';

// Config directory.
$settings['config_sync_directory'] = $app_root . '/../config/sync';

// Database settings.
$databases['default']['default'] = [
  'database' => $_ENV['DB_NAME'],
  'username' => $_ENV['DB_USERNAME'],
  'password' => $_ENV['DB_PASSWORD'],
  'prefix' => '',
  'host' => $_ENV['DB_HOST'],
  'port' => $_ENV['DB_PORT'] ?: '3306',
  'namespace' => 'Drupal\\Core\\Database\\Driver\\mysql',
  'driver' => 'mysql',
];

// Mark unused files as temporary for deletion.
$config['file.settings']['make_unused_managed_files_temporary'] = TRUE;

// Other settings.
$settings['container_yamls'][] = $app_root . '/' . $site_path . '/services.yml';
$settings['update_free_access'] = FALSE;
$settings['entity_update_batch_size'] = 50;
$settings['entity_update_backup'] = TRUE;
$settings['file_scan_ignore_directories'] = [
  'node_modules',
  'bower_components',
];

// If debug is enabled, override some config.
if ($debug) {
  $settings['container_yamls'][] = $app_root . '/sites/development.services.yml';
  $settings['cache']['default'] = 'cache.backend.null';
  $settings['cache']['bins']['render'] = 'cache.backend.null';
  $settings['cache']['bins']['dynamic_page_cache'] = 'cache.backend.null';
  $settings['rebuild_access'] = TRUE;
  $settings['skip_permissions_hardening'] = TRUE;

  $config['system.logging']['error_level'] = 'verbose';
  $config['system.performance']['css']['preprocess'] = FALSE;
  $config['system.performance']['js']['preprocess'] = FALSE;
  $config['minifyhtml.config']['minify'] = FALSE;
  $config['minifyhtml.config']['strip_comments'] = FALSE;
  $config['advagg.settings']['enabled'] = FALSE;
}

if (!empty($_ENV['PROJECT_ENV']) && file_exists($app_root . '/' . $site_path . '/settings.' . $_ENV['PROJECT_ENV'] . '.php')) {
  include $app_root . '/' . $site_path . '/settings.' . $_ENV['PROJECT_ENV'] . '.php';
}
